#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <sisio.h>

void vainscv( inbuf, inlen, outbuf, outlen )

	char *	inbuf;
	int *	inlen;
	char *	outbuf;
	int *	outlen;

{
	int	start, number, length, perword, ier;

	memcpy( outbuf + 0, inbuf + 0, *inlen - 0 );
	*outlen = 0 + ( *inlen - 0 );
}
